@@ -154,6 +154,8 @@ History:
                     Added inMethodCall method.
 2011-06-16 ROwen    Ditched obsolete "except (SystemExit, KeyboardInterrupt): raise" code
 2014-05-07 ROwen    Changed is str test to use basestring.
+2014-07-21 ROwen    Disabling the widget now makes the widget lose focus, which is what users expect
+                    and saves unsaved edits.
 """
 __all__ = ['StrEntry', 'ASCIIEntry', 'FloatEntry', 'IntEntry', 'DMSEntry']
 
@@ -617,11 +619,16 @@ class _BaseEntry (Tkinter.Entry, RO.AddCallback.BaseMixin,
         
     def setEnable(self, doEnable):
         """Changes the enable state.
+
+        Also, if disabling and have focus then lose focus. This is what users expect and saves unsaved edits.
         """
         if doEnable:
             self.configure(state="normal")
         else:
             self.configure(state="disabled")
+            if self.focus_get() == self:
+                self.winfo_toplevel().focus()
+            self.neatenDisplay()
     
     def setEntryError(self, errMsg):
         """Call to report or clear the entry error.
